# Context related

Here are the metrics for evaluate the context related attributes in your RAG model.

````{grid}
:gutter: 2

```{grid-item-card} 📜 Context Relevancy
:link: context-relevancy
:link-type: ref

These metrics evaluate how well the provided context matches the given question, ensuring relevance and coherence.
```

```{grid-item-card} 📜 Context Utilization
:link: response-utilization
:link-type: ref

This measures how effectively the response uses the surrounding context to provide relevant information.
```

````

```{toctree}
:hidden:

context_relevancy
context_utilization
```